@@ -79,7 +79,7 @@ WPScan::DB::DynamicFinders::Theme.versions_finders_configs.each do |slug, config
                 end
 
                 it 'returns the expected version/s' do
-                  found = [*finder.passive]
+                  found = Array(finder.passive)
 
                   expect(found).to_not be_empty
 
@@ -109,7 +109,7 @@ WPScan::DB::DynamicFinders::Theme.versions_finders_configs.each do |slug, config
                 end
 
                 it 'returns the expected version/s' do
-                  found = [*finder.passive]
+                  found = Array(finder.passive)
 
                   expect(found).to_not be_empty
 
@@ -154,7 +154,7 @@ WPScan::DB::DynamicFinders::Theme.versions_finders_configs.each do |slug, config
             end
 
             it 'returns the expected version' do
-              found = [*finder.aggressive]
+              found = Array(finder.aggressive)
 
               expect(found).to_not be_empty
 
